Module message_io::encoding [−][src]
Frame encoding to convert a data stream into packets. It can be used as a utility to build adapters.
Structs
| Decoder | Used to decoded one message from several/partial data chunks |
Constants
| PADDING |
Functions
| decode_size | Decodes an encoded value in a buffer.
The function returns the message size or none if the buffer is less than |
| encode_size | Encode a message, returning the bytes that must be sent before the message. |
Type Definitions
| Padding |