Adapter

Trait Adapter 

pub trait Adapter: Send + Sync {
    type Remote: Remote;
    type Local: Local<Remote = Self::Remote>;
}
High level trait to represent an adapter for a transport protocol. The adapter is only used to identify the resources of your adapter.

Required Associated Types

type Remote: Remote

Resource type used to identify remote connections and send/receive from remote this endpoints (e.g. TcpStream) This can be considerered the resource used for client connections.

type Local: Local<Remote = Self::Remote>

Resource type used to accept new connections (e.g. TcpListener) This can be considerered the resource used for server listenings.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors