Enum message_io::network::NetEvent [−][src]
Input network events.
Variants
Input message received by the network.
Connected(Endpoint)New endpoint has been connected to a listener.
This event will be sent only in connection oriented protocols as Transport::Tcp.
Disconnected(Endpoint)This event is only dispatched when a connection is lost.
Call to Network::remove() will NOT generate the event.
When this event is received, the resource is considered already removed.
A NetEvent::Message event will never be generated after this event from the endpoint.
This event will be sent only in connection oriented protocols as Transport::Tcp.
Because UDP is not connection oriented, the event can no be detected.
Implementations
impl NetEvent[src]
pub fn from_adapter(
endpoint: Endpoint,
adapter_event: AdapterEvent<'_>
) -> NetEvent[src]
endpoint: Endpoint,
adapter_event: AdapterEvent<'_>
) -> NetEvent
Created a NetEvent from an AdapterEvent.