[−][src]Module message_io::network_manager
Structs
| NetworkManager | NetworkManager allows to manage the network easier. It is in mainly in charge to transform raw data from the network into message events and vice versa. |
Enums
| NetEvent | Input network events. |
| TransportProtocol | Used to define the protocol when a connection/listener is created. |
Type Definitions
| Endpoint | Alias to improve the management of the connection ids. |