pub trait Adapter: Send + Sync {
type Remote: Remote;
type Local: Local<Remote = Self::Remote>;
}Expand description
High level trait to represent an adapter for a transport protocol. The adapter is only used to identify the resources of your adapter.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".